@@ -9,6 +9,7 @@ from django import forms
 from django.conf import settings
 from django.contrib.admin.widgets import RelatedFieldWidgetWrapper
 from django.db import models
+from django.db.models.manager import Manager
 from django.forms import widgets
 from django.forms.util import flatatt
 from django.utils.encoding import smart_unicode
@@ -224,7 +225,11 @@ class ReadOnlyWidget(forms.Widget):
 
     def __init__(self, original_value, display_value):
         if display_value is None:
-            display_value = original_value or u''
+            if isinstance(original_value, Manager) and hasattr(original_value, 'all'):
+                display_value = u', '.join(
+                    [element.__unicode__() for element in original_value.all()])
+            else:
+                display_value = original_value or u''
         if isinstance(original_value, models.Model):
             original_value = original_value.pk
         self.original_value = original_value
